@@ -253,5 +253,5 @@ import 'models.pbgrpc.dart';
     # registerClient(EmployeeMethodsClient(channel, interceptors: [AuthInterceptor(token)]));
     # }
 
-    with open(settings.DART_RPC_METHODS_FILE, 'w') as f:
+    with open(settings.dart_proto_folder + '/rpc_methods.dart', 'w') as f:
         f.write(content)
