@@ -114,8 +114,14 @@ class Message:
         # via kwargs. In this way to user can use the Message class as if it would be a
         # proto-message and we can extend our functionality around it.
         name = cls.__name__
-        proto = name_to_grpc_message_or_method(name)()
-        proto = ParseDict(kwargs, proto, ignore_unknown_fields=True)
+        try:
+            proto = name_to_grpc_message_or_method(name)()
+            proto = ParseDict(kwargs, proto, ignore_unknown_fields=True)
+        except Exception as e:
+            # TODO: this is called in regen, but there is no proto-file as it is just generated
+            # right now. Thus name_to_grpc_message_or_method(name) returns None, which causes an error
+            # but this should be the normal case at this state, thus there is an design error here 
+            proto = {}
         # We use the Message class to wrap the proto-message-class which holds the actual data.
         # thus we set the data into the proto-attribute and whenever someone asks us for data
         # we take it from there
